const config = {};
config.API_URL = 'http://localhost:9000';
export default config;
